use Test::More tests => 1;

BEGIN {
require_ok( 'CGI::Application::Plugin::View::HTML::Template' );
}

diag( "Testing CGI::Application::Plugin::View::HTML::Template $CGI::Application::Plugin::View::HTML::Template::VERSION" );
